kind_label

Function kind_label 

fn kind_label(kind: i32) -> String
Map atlas’s CapabilityProvider.kind enum to the lowercase label the prompt uses. Atlas is the source of truth for a provider’s kind.