pub struct FinishVoiceCaptureRequest {
pub session_id: String,
}Fields
session_id: StringTrait Implementations
Sourceimpl Clone for FinishVoiceCaptureRequest
impl Clone for FinishVoiceCaptureRequest
Sourcefn clone(&self) -> FinishVoiceCaptureRequest
fn clone(&self) -> FinishVoiceCaptureRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FinishVoiceCaptureRequest
impl Debug for FinishVoiceCaptureRequest
Sourceimpl Default for FinishVoiceCaptureRequest
impl Default for FinishVoiceCaptureRequest
impl Eq for FinishVoiceCaptureRequest
Sourceimpl Hash for FinishVoiceCaptureRequest
impl Hash for FinishVoiceCaptureRequest
Sourceimpl Message for FinishVoiceCaptureRequest
impl Message for FinishVoiceCaptureRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FinishVoiceCaptureRequest
impl PartialEq for FinishVoiceCaptureRequest
Sourcefn eq(&self, other: &FinishVoiceCaptureRequest) -> bool
fn eq(&self, other: &FinishVoiceCaptureRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FinishVoiceCaptureRequest