fn plan_completion_state(results: &[RtdlNodeState], any_failed: bool) -> StringExpand description
Pick the plan-level completion state shown in the forest completion log.
fn plan_completion_state(results: &[RtdlNodeState], any_failed: bool) -> StringPick the plan-level completion state shown in the forest completion log.